@@ -1,7 +1,7 @@
 #!/usr/bin/perl
 
 package Cache::Cascade;
-use Squirrel;
+use Any::Moose;
 
 use Carp qw/croak/;
 
@@ -13,7 +13,7 @@ sub _eval {
 
 use namespace::clean -except => [qw(meta)];
 
-our $VERSION = "0.04";
+our $VERSION = "0.05";
 
 has caches => (
 	isa => "ArrayRef",
